slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPCISSSetRefinement

Sets the values of various refinement parameters in the CISS solver.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPCISSSetRefinement(PEP pep,PetscInt inner,PetscInt blsize)

Logically Collective on pep

### Input Parameters

| pep | - the polynomial eigensolver context
| inner | - number of iterative refinement iterations (inner loop)
| blsize | - number of iterative refinement iterations (blocksize loop)

### Options Database Keys

| -pep_ciss_refine_inner | - Sets number of inner iterations
| -pep_ciss_refine_blocksize | - Sets number of blocksize iterations

### See Also

PEPCISSGetRefinement()

### Level

advanced

### Location

src/pep/impls/ciss/pciss.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages